# Arcade ImGui

[The Python Arcade Library](https://arcade.academy/) + [pyimgui](https://github.com/swistakm/pyimgui) = :heart:

:package: [Package](https://pypi.org/project/arcade-imgui/)

## Prerequisite

Get [Poetry](https://python-poetry.org/)

## Clone

Clone the repository and change directory

       git clone https://github.com/kfields/arcade-imgui.git
       cd arcade-imgui

## Run the Demo

        cd imdemo
        poetry install
        poetry shell
        python imdemo

### Individual Examples

        python examples/bullet.py
        python examples/colors.py
        etc ...

## Run the ImFlo Demo

        cd imflo
        poetry install
        poetry shell
        python imdemo
